==> common-cache-client-redis-1.0.1-20180103.065713-1-sources.jar: com/chinamclound/common/cache/client/RedisMapCommonClient.java <==
package com.chinamclound.common.cache.client;

import com.google.common.collect.Maps;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.BoundHashOperations;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * Created with IntelliJ IDEA.
 * User: chenzhiwei
 * Date: 17/5/11
 * Time: 下午1:44
 * 参考：http://www.cnblogs.com/0201zcr/p/4987561.html
 */
@Component("redisMapCommonClient")
public class RedisMapCommonClient<K, HK, HV> {

    //Spring Boot已为我们配置RedisTemplate，在此处可以直接注入
    @Autowired
    @Resource(name = "redisTemplate")
    private RedisTemplate<K, Object> redisTemplate;

    /**
     * 保存Map数据到指定的key中
     *
     * @param cacheKey
     * @param cacheMap
     * @param expireTime:过期时间，单位秒
     * @return
     * @see com.chinamcloud.common.cache.constant.CacheConstant
     */
    public boolean putCacheMap(K cacheKey, Map<HK, HV> cacheMap, Integer expireTime) {
        BoundHashOperations<K, HK, HV> hashOperations = redisTemplate.boundHashOps(cacheKey);
        hashOperations.putAll(cacheMap);
        hashOperations.expire(expireTime, TimeUnit.SECONDS);
        return true;
    }

    /**
     * 返回指定key的Map中的相应key数据（只返回存在的数据）
     *
     * @param cacheKey
     */
    public Map<HK, HV> getCacheMap(K cacheKey, List<HK> mapKeyList) {
        BoundHashOperations<K, HK, HV> hashOperations = redisTemplate.boundHashOps(cacheKey);
        List<HV> mapValueList = hashOperations.multiGet(mapKeyList);
        Map<HK, HV> resultMap = Maps.newHashMap();
        for (int i = 0; i < mapValueList.size(); i++) {
            HV mapValue = mapValueList.get(i);
            if (mapValue != null) {
                resultMap.put(mapKeyList.get(i), mapValue);
            }
        }
        return resultMap;
    }

    /**
     * 删除map中指定的key
     *
     * @param cacheKey
     * @param mapKeyList
     * @return :删除成功的个数
     */
    public Long delete(K cacheKey, List<HK> mapKeyList) {
        BoundHashOperations<K, HK, HV> hashOperations = redisTemplate.boundHashOps(cacheKey);
        return hashOperations.delete(mapKeyList.toArray());
    }

    /**
     * 删除并返回原存储的值
     *
     * @param cacheKey
     * @param mapKey
     * @return 返回删除的key的值
     */
    public HV deleteAndReturnValueByObject(final K cacheKey, final HK mapKey) {
        BoundHashOperations<K, HK, HV> hashOperations = redisTemplate.boundHashOps(cacheKey);
        HV mapValue = hashOperations.get(mapKey);
        hashOperations.delete(mapKey);
        return mapValue;
    }
}

==> common-cache-client-redis-1.0.1-20180110.102015-2-sources.jar: com/chinamclound/common/cache/client/RedisMapCommonClient.java <==
package com.chinamclound.common.cache.client;

import com.chinamclound.common.cache.properties.RedisCustomizeProperties;
import com.google.common.collect.Maps;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.BoundHashOperations;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * Created with IntelliJ IDEA.
 * User: chenzhiwei
 * Date: 17/5/11
 * Time: 下午1:44
 * 参考：http://www.cnblogs.com/0201zcr/p/4987561.html
 */
@Component("redisMapCommonClient")
public class RedisMapCommonClient<K, HK, HV> {

    //Spring Boot已为我们配置RedisTemplate，在此处可以直接注入
    @Autowired
    @Resource(name = "redisTemplate")
    private RedisTemplate<K, Object> redisTemplate;
    @Autowired
    private RedisCustomizeProperties redisCustomizeProperties;


    /**
     * 指定key是否存在
     *
     * @param key
     * @return
     */
    public boolean isExist(K key) {
        return redisTemplate.hasKey(key);
    }

    /**
     * 保存Map数据到指定的key中
     *
     * @param cacheKey
     * @param cacheMap
     * @return
     * @see com.chinamcloud.common.cache.constant.CacheConstant
     */
    public boolean putCacheMap(K cacheKey, Map<HK, HV> cacheMap) {
        return putCacheMap(cacheKey,cacheMap,redisCustomizeProperties.getDefaultExpiration());
    }

    /**
     * 保存Map数据到指定的key中
     *
     * @param cacheKey
     * @param cacheMap
     * @param expireTime:过期时间，单位秒
     * @return
     * @see com.chinamcloud.common.cache.constant.CacheConstant
     */
    public boolean putCacheMap(K cacheKey, Map<HK, HV> cacheMap, Integer expireTime) {
        BoundHashOperations<K, HK, HV> hashOperations = redisTemplate.boundHashOps(cacheKey);
        hashOperations.putAll(cacheMap);
        hashOperations.expire(expireTime, TimeUnit.SECONDS);
        return true;
    }

    /**
     * 保存Map数据到指定的key中
     *
     * @param cacheKey
     * @param hk
     * @param hv
     * @return
     * @see com.chinamcloud.common.cache.constant.CacheConstant
     */
    public boolean putCacheMap(K cacheKey, HK hk, HV hv) {
        putCacheMap(cacheKey,hk,hv,redisCustomizeProperties.getDefaultExpiration());
        return true;
    }

    /**
     * 保存Map数据到指定的key中
     *
     * @param cacheKey
     * @param hk
     * @param hv
     * @param expireTime:过期时间，单位秒
     * @return
     * @see com.chinamcloud.common.cache.constant.CacheConstant
     */
    public boolean putCacheMap(K cacheKey, HK hk, HV hv, Integer expireTime) {
        BoundHashOperations<K, HK, HV> hashOperations = redisTemplate.boundHashOps(cacheKey);
        hashOperations.put(hk,hv);
        hashOperations.expire(expireTime, TimeUnit.SECONDS);
        return true;
    }

    /**
     * 返回指定key的Map中的相应key数据（只返回存在的数据）
     *
     * @param cacheKey
     */
    public Map<HK, HV> getCacheMap(K cacheKey, List<HK> mapKeyList) {
        BoundHashOperations<K, HK, HV> hashOperations = redisTemplate.boundHashOps(cacheKey);
        List<HV> mapValueList = hashOperations.multiGet(mapKeyList);
        Map<HK, HV> resultMap = Maps.newHashMap();
        for (int i = 0; i < mapValueList.size(); i++) {
            HV mapValue = mapValueList.get(i);
            if (mapValue != null) {
                resultMap.put(mapKeyList.get(i), mapValue);
            }
        }
        return resultMap;
    }


    /**
     * 删除map中指定的key
     *
     * @param cacheKey
     * @param hk
     * @return :删除成功的个数
     */
    public Long delete(K cacheKey, HK ...hk) {
        BoundHashOperations<K, HK, HV> hashOperations = redisTemplate.boundHashOps(cacheKey);
        return hashOperations.delete(hk);
    }

    /**
     * 删除并返回原存储的值
     *
     * @param cacheKey
     * @param mapKey
     * @return 返回删除的key的值
     */
    public HV deleteAndReturnValueByObject(final K cacheKey, final HK mapKey) {
        BoundHashOperations<K, HK, HV> hashOperations = redisTemplate.boundHashOps(cacheKey);
        HV mapValue = hashOperations.get(mapKey);
        hashOperations.delete(mapKey);
        return mapValue;
    }

}
